
# q-expansion of newform 936.4.c.d, downloaded from the LMFDB on 10 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 936
weight = 4
poly_data = [2455943229260676, 0, 16656245475356664, 0, 4590326443525329, 0, 385506177829060, 0, 15714484512880, 0, 366523224996, 0, 5240196398, 0, 46787036, 0, 254556, 0, 772, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[575809116648430994539865319073366684754388, 0, 643954498690965395440739576328864832320216, 0, 105872551112274068598350583298945720500741, 0, 4924376021418511620527775434749629874636, 0, 80101185137893682477063121048735919368, 0, -63644816585342345163216370133000211, 0, -16901838350741711721932579653074961, 0, -204298971838055238926583857454144, 0, -1009679268183277948195874537100, 0, -1850242331945425031221585733, 0], 21969333352482437744705260379034237689190], [[-3897226543204584961413930046657872560249604, 0, -2214320505700767180870498033676801247811468, 0, -196093464952276759852473725592302266533813, 0, -7107830642570851791710642905139738727893, 0, -119684726232883231378105544641392638499, 0, -681821895344705343663872018659790247, 0, 6353484003583434709299245146512353, 0, 118209074198415042534942616467537, 0, 651402791132332232768261422155, 0, 1258842492853334722460597479, 0], 14646222234988291829803506919356158459460], [[-192882498152638180049623589341677264963, 0, -79556707591830540918514697182998752268, 0, -21217734521620336482782373280476618639, 0, -1642881540268505652358298705980908953, 0, -58903159176112123086445857210050451, 0, -1150617288284328938953996601691147, 0, -12992393957240911573789686099229, 0, -84617421826263388065211629891, 0, -294898366412946959818816029, 0, -425523317051969798813477, 0], 1269170037693959430658882748644381149], [[4053394835514469262095514162178168872689704, 0, 3542761820852741071079521404067614637218348, 0, 571045679178374216896878296686368812441358, 0, 39036872642213769154712042895417562629823, 0, 1370440867075408237710950219270164370979, 0, 27139631696057404586141841827200613742, 0, 315360018975447575389399629202821002, 0, 2130292282028784151913240228143833, 0, 7735053221778600186535685709105, 0, 11654667505356774839705064826, 0], 21969333352482437744705260379034237689190], [[-4590961526239139150054974858198469382432396, 0, -6651332385006523517673091133009704437137292, 0, -1361342916367138653080739256843244635394487, 0, -95285354471907953039385103560548017806457, 0, -3274435311619263886424068098070965586371, 0, -63343070555062989169678988510936068773, 0, -723603830557578686618287711198189253, 0, -4835399755713690916140140402347347, 0, -17444993317560900704019134162925, 0, -26189720033899650359666628619, 0], 43938666704964875489410520758068475378380], [[2132298149940948029539345163182905679386, 0, -2627258296953353453273439185043194748936, 0, -688452188385795075098091190473554211447, 0, -51250472341843128398301403211566194868, 0, -1769428223088095948050151364979765410, 0, -33413574278319803226349524699917406, 0, -366816311151003793501087858866875, 0, -2336517902815961378249948312220, 0, -8007252162554524603602180648, 0, -11413822135674045451840234, 0], 19037550565409391459883241229665717235], [[955413385899049326224298992593920478272, 0, 2665934562721251634533900224919883442088, 0, 709015367134840622486069780302533638016, 0, 54589287797004908741494440863938221634, 0, 1951806759006520930847974366484341500, 0, 38268065162235644657847094774312158, 0, 437356028779540233286591913011760, 0, 2905938783075494911613344952190, 0, 10397667734125748947562749284, 0, 15471185566455937926493882, 0], 19037550565409391459883241229665717235], [[-680404288076887263748076989558542083407236, 0, 679258362898839424531751258657440751651268, 0, 258159033187034343961584348771783855919539, 0, 20191511827238755131464302412423120253587, 0, 701000877558441277880995944917601590787, 0, 13166478849828614433646746485506639803, 0, 143361686243364409266622186687283641, 0, 905787160579363476312839573696241, 0, 3083130960639061009501939171149, 0, 4373059840329241088230921109, 0], 4393866670496487548941052075806847537838], [[0, -35214703534395544026665587025186182116, 0, -12001647955633054143863681621700129420, 0, -1073746885050910263510804920663858319, 0, -43222767797038712703978604681917968, 0, -927798022637785969948417650704013, 0, -11261141160924977240630543263368, 0, -76339284383232329809251808105, 0, -257362534146866691710735220, 0, -246463139692366875185247, 0, 413015258861771519680], 818734991371318524632206079255685813], [[0, -1384200417875204992302327043553246508824064324, 0, -461382674321007752455121573315195890052001192, 0, -40420567295703336067601742338180743389562125, 0, -1735013106327097903062563194244087742161228, 0, -42747818674539277423795518691230931370337, 0, -638239316182266493677241631708600900124, 0, -5853062600908441981473461176632228871, 0, -32214734730831464395557955955195124, 0, -97708742239807133297124398633319, 0, -125638926273611156192997987860], 139770802543549809870960854855538786750350280], [[0, 1594293186354799194992768531465348562860838024948, 0, 362308593378830284928388199384199993306702529720, 0, 27805189951694693926097075711090059342020812023, 0, 1086294544056832095486034048583283700334908951, 0, 24769952748860825161833919339929559143967401, 0, 350308565358731477500801250670479566331801, 0, 3130335538948292055685910101211603368973, 0, 17271860291096952594912653443245067677, 0, 53837474987764230221158205604295759, 0, 72516093654754234942955916625051], 26882584355876080098514804417215293318317370520], [[-1383862589696193213671548970549498164869182042292, 29409062675857770260120881597475141272653397816416, 677819554882390181063979049681456591715265870432, 6573796721032382774050292035106463156982573272150, 174735641413319977517865507809754278964817507404, 474968059823930656164801539709972116545129710951, 12657120940593196558788996022226633813487199376, 15872418141256381685500737773242093929814230877, 446753523211444336898899503243033231061541010, 286726365791601473692687566871011392791733802, 8859379991868727766336087843077655285053332, 2947072320079986976723299516154367579149542, 103359821700618902858474311381833612123160, 16710278039468930806330904615386256256941, 702493734197356889697570193348797776280, 43100550333109277910857849637506691099, 2568347383282610560416507322824407106, -328941253191632062224375034470162, 3895791638452653636589656929749748, -152364824984684459895490203702968], 40323876533814120147772206625822939977476055780], [[0, 1487985119815560856129742654529260050817036810196, 0, 362077550466019215174289935635145104814096930228, 0, 32394397230715899209457032979443017007497896669, 0, 1495798222618213783399659417840450616657738069, 0, 39277091311019011645408527124146068366573385, 0, 615745388388771550317784411795493339245365, 0, 5854917155781853164857856507713162352431, 0, 33025388396059799885827284567740359311, 0, 101439491391674537053461245364299247, 0, 130482948352229826555014432969851], 8064775306762824029554441325164587995495211156], [[0, -7295670176872462172724316908973625266607538192, 0, -2747859947191603212172429602408043418678829456, 0, -295977523485004921708587331132041538720654800, 0, -14934382640653334091341625768120067208042534, 0, -417421001838206881836330297436108747464546, 0, -6952229723485193057418570910842734747277, 0, -70602636512811893016450010850799509818, 0, -428310491288974920251423996700920412, 0, -1424680455663770202274780004533932, 0, -1996480031463917415032775975485], 69885401271774904935480427427769393375175140], [[1383862589696193213671548970549498164869182042292, -2494726825697875840636916649537856512022821948876, -677819554882390181063979049681456591715265870432, -821383140985434328250047420888575752039949484470, -174735641413319977517865507809754278964817507404, -112190714619513383261706430710908312369977396716, -12657120940593196558788996022226633813487199376, -6908987167900431657163090100301085957534068542, -446753523211444336898899503243033231061541010, -222897907615976888069442210058282048816690977, -8859379991868727766336087843077655285053332, -4122046182945554696497527967957803106318977, -103359821700618902858474311381833612123160, -45304534223713234979290592837474026000756, -702493734197356889697570193348797776280, -292299446602457444641482471316959325014, -2568347383282610560416507322824407106, -1021178352680643254399551123637683263, -3895791638452653636589656929749748, -1488947964130959420994155953242337], 40323876533814120147772206625822939977476055780], [[1383862589696193213671548970549498164869182042292, 2494726825697875840636916649537856512022821948876, -677819554882390181063979049681456591715265870432, 821383140985434328250047420888575752039949484470, -174735641413319977517865507809754278964817507404, 112190714619513383261706430710908312369977396716, -12657120940593196558788996022226633813487199376, 6908987167900431657163090100301085957534068542, -446753523211444336898899503243033231061541010, 222897907615976888069442210058282048816690977, -8859379991868727766336087843077655285053332, 4122046182945554696497527967957803106318977, -103359821700618902858474311381833612123160, 45304534223713234979290592837474026000756, -702493734197356889697570193348797776280, 292299446602457444641482471316959325014, -2568347383282610560416507322824407106, 1021178352680643254399551123637683263, -3895791638452653636589656929749748, 1488947964130959420994155953242337], 40323876533814120147772206625822939977476055780], [[0, -110984238003041255243097501454897293005959008204, 0, -32729371795845929110984973591251573824323798232, 0, -2083286662780582081840546903755028336021108455, 0, -52369931237268991879766183022891254419770268, 0, -478928523412038810611512190286144208552947, 0, 2945802854244761786006599495221780997956, 0, 105192863205163525818968877178479013099, 0, 956293619329325230366351547281929276, 0, 3938621547072857560470193471737051, 0, 6299394540143145471628280730860], 139770802543549809870960854855538786750350280], [[0, -327819884329866456904605042134078055499828788, 0, -108103300761669903188213193319728736358901864, 0, -9163376650891094051625080794729395334743765, 0, -366164426037085540692429353267794270014886, 0, -8391112954831245371189331171139278048399, 0, -119791216094010840615967625492269951893, 0, -1090819601101811679516173535411778097, 0, -6174909795622111745164838438704068, 0, -19781434159822491130269176214063, 0, -27313603592254995094443451405], 280664262135642188495905331035218447289860], [[0, 19822814539415000088022094366345324355527896459044, 0, 3650912404456815110610069675787049649566615590320, 0, 111185173713986456967014284937943780961219487799, 0, -4892002909845105869850037720279388930246071417, 0, -351282534291683440078573152237047213991269967, 0, -8500519798155722133280370395773938907284127, 0, -106839384694975938029153695364261263252691, 0, -745837378700978062282661267475656076819, 0, -2742456295910231149257743773602006633, 0, -4143659064875314965001427427054277], 40323876533814120147772206625822939977476055780]]

hecke_ring_character_values = [[703, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [469, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [209, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [145, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [-4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 1, 0, 0, 0, 1, 0], [-15, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 4, -3, 0, 0, 0, 2, 0, 0, 1, -1, 0], [0, 0, 2, 0, 2, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -7, 0, 0, 0, 1, 0, 0, 1, 0, 0], [6, 0, 0, 2, 0, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -2, -1, 0, -4, 2, 0, 0, 3], [0, 0, 0, 0, 0, 0, 0, 0, 0, 6, -10, 0, 0, 0, 4, 0, 0, 2, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, -1, -5, 0, 2, -3, 0, 0, -2], [20, 0, 0, 4, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -2, -3, 0, 0, 0, -5, 0, 0, 1, 2, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 1, 0, 0, 0, 5, 0, 0, 2, 1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 9, 0, 4, -7, 0, 0, 2], [0, 8, 4, 0, 2, -7, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [137, 0, 0, 3, 0, 0, -5, 4, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0], [0, 0, -5, 0, 7, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20, 3, -1, 0, 9, -6, 0, 0, -4], [0, 17, 0, 0, 8, -2, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-94, 0, 0, -2, 0, 0, 6, 11, 0, 0, 0, 0, 0, 0, 0, 8, 8, 0, 0, 0], [0, 8, -9, 0, -1, -8, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 21, 0, 0, 0, -5, 0, 0, 4, -1, 0], [65, 0, 0, 7, 0, 0, 5, -6, 0, 0, 0, 0, 0, 0, 0, 13, 13, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 3, 0, 0, 0, -20, 0, 0, 4, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -27, 4, 20, 0, -8, 12, 0, 0, 2], [-68, 0, 0, 14, 0, 0, 1, -23, 0, 0, 0, 0, 0, 0, 0, -15, -15, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 29, -2, 15, 0, -20, 18, 0, 0, -3], [0, 0, 0, 0, 0, 0, 0, 0, 0, 32, -59, 0, 0, 0, -10, 0, 0, 5, -1, 0], [0, -10, 2, 0, 10, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -8, 3, 0, 3, 22, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-200, 0, 0, 6, 0, 0, 3, 17, 0, 0, 0, 0, 0, 0, 0, -21, -21, 0, 0, 0], [0, -4, -4, 0, 12, -5, 0, 0, -8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, -1, 3, 0, 20, -21, 0, 0, 2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 38, -115, 0, 0, 0, 58, 0, 0, 8, -6, 0], [-50, 0, 0, -14, 0, 0, 10, -11, 0, 0, 0, 0, 0, 0, 0, 20, 20, 0, 0, 0], [626, 0, 0, -10, 0, 0, -14, 18, 0, 0, 0, 0, 0, 0, 0, 30, 30, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 63, 4, 2, 0, -16, 20, 0, 0, -5], [0, 0, 0, 0, 0, 0, 0, 0, 0, -22, -23, 0, 0, 0, 35, 0, 0, -3, 8, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 76, 4, -16, 0, 27, -23, 0, 0, 8], [0, -24, 6, 0, 4, -14, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -20, 17, 0, 0, 0, -60, 0, 0, 5, -13, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -84, 4, -4, 0, 38, -34, 0, 0, -12], [0, 16, -28, 0, -4, 2, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, -16, 0, -20, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 32, 10, 0, 2, -18, 0, 0, -16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 34, -1, 0, 12, 20, 0, 0, -12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, -8, -4, 0, -24, 16, 0, 0, 13], [-510, 0, 0, 0, 0, 0, 4, -34, 0, 0, 0, 0, 0, 0, 0, -36, -36, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 33, -81, 0, 0, 0, -125, 0, 0, -10, 3, 0], [178, 0, 0, 6, 0, 0, -10, 52, 0, 0, 0, 0, 0, 0, 0, 42, 42, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -78, 277, 0, 0, 0, 6, 0, 0, -8, 6, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -89, -22, -15, 0, -72, 50, 0, 0, -3], [0, 16, 14, 0, -10, -35, 0, 0, -8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-20, 0, 0, -12, 0, 0, 2, -53, 0, 0, 0, 0, 0, 0, 0, -31, -31, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -156, 13, 0, 0, 0, 88, 0, 0, -16, 12, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -151, 20, -3, 0, -56, 76, 0, 0, -2], [100, 0, 0, -4, 0, 0, -14, 57, 0, 0, 0, 0, 0, 0, 0, -33, -33, 0, 0, 0], [0, -56, 14, 0, 10, 16, 0, 0, -16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -156, -10, 50, 0, 39, -49, 0, 0, -8], [0, 0, 0, 0, 0, 0, 0, 0, 0, -3, -261, 0, 0, 0, 107, 0, 0, -20, 7, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 118, 156, 0, 0, 0, 110, 0, 0, -4, -9, 0], [-431, 0, 0, 19, 0, 0, 55, 14, 0, 0, 0, 0, 0, 0, 0, 7, 7, 0, 0, 0], [-1444, 0, 0, -36, 0, 0, 20, 4, 0, 0, 0, 0, 0, 0, 0, -15, -15, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 193, 18, -5, 0, -60, 78, 0, 0, -23], [0, 0, 0, 0, 0, 0, 0, 0, 0, -14, -216, 0, 0, 0, 62, 0, 0, -4, -21, 0], [0, -20, 7, 0, -40, 26, 0, 0, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -392, -2, -26, 0, 23, -25, 0, 0, -8], [0, 0, 0, 0, 0, 0, 0, 0, 0, 153, 421, 0, 0, 0, 83, 0, 0, -18, 11, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 280, 13, 41, 0, 24, -11, 0, 0, -34], [0, -72, 33, 0, -11, 2, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 280, -6, 58, 0, 43, -49, 0, 0, -36], [0, 0, 0, 0, 0, 0, 0, 0, 0, 42, 712, 0, 0, 0, -116, 0, 0, -16, 13, 0], [-1040, 0, 0, 40, 0, 0, 23, -56, 0, 0, 0, 0, 0, 0, 0, -28, -28, 0, 0, 0], [-1069, 0, 0, -7, 0, 0, -7, 86, 0, 0, 0, 0, 0, 0, 0, -23, -23, 0, 0, 0], [0, 8, -23, 0, -47, 26, 0, 0, -16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -179, 609, 0, 0, 0, -81, 0, 0, -6, -9, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -360, 11, 47, 0, 12, -1, 0, 0, 58], [0, 0, 0, 0, 0, 0, 0, 0, 0, -112, 321, 0, 0, 0, -180, 0, 0, -28, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -101, 32, -30, 0, 96, -64, 0, 0, -16], [0, -80, -72, 0, -20, -8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 260, -373, 0, 0, 0, -52, 0, 0, -29, 3, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -361, -28, 66, 0, 64, -92, 0, 0, -11], [0, 152, 62, 0, -6, -48, 0, 0, -12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -375, -20, -25, 0, -60, 40, 0, 0, -20], [0, 172, -46, 0, -38, 6, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 66, -627, 0, 0, 0, 10, 0, 0, -20, 22, 0], [0, 29, 8, 0, 8, -152, 0, 0, -20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [3165, 0, 0, 35, 0, 0, -51, 6, 0, 0, 0, 0, 0, 0, 0, 53, 53, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 220, -20, 112, 0, -49, 29, 0, 0, 40], [355, 0, 0, -67, 0, 0, -49, -12, 0, 0, 0, 0, 0, 0, 0, 79, 79, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 546, 601, 0, 0, 0, -78, 0, 0, 16, -2, 0], [0, -104, 17, 0, 9, -44, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 18, 34, 0, -4, 20, 0, 0, -36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2274, 0, 0, -6, 0, 0, 90, 22, 0, 0, 0, 0, 0, 0, 0, 38, 38, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 516, 58, -22, 0, 4, 54, 0, 0, -4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 240, 456, 0, 0, 0, 49, 0, 0, 4, -24, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 411, -591, 0, 0, 0, -231, 0, 0, 6, 25, 0], [0, -140, -64, 0, 0, 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1884, 0, 0, 44, 0, 0, -2, -11, 0, 0, 0, 0, 0, 0, 0, 37, 37, 0, 0, 0], [2477, 0, 0, -49, 0, 0, -49, 26, 0, 0, 0, 0, 0, 0, 0, -193, -193, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 5, -59, 0, -27, 32, 0, 0, -76], [0, 0, 0, 0, 0, 0, 0, 0, 0, -19, 223, 0, 0, 0, 323, 0, 0, 28, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -61, 18, -11, 0, -80, 98, 0, 0, 17], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 363, 20, 54, 0, 216, -196, 0, 0, -25], [0, 155, -32, 0, -64, 48, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -509, -2, 93, 0, -4, 2, 0, 0, 19], [0, 8, -16, 0, 120, 78, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -38, -17, 0, -32, -18, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -144, 66, 0, -50, -74, 0, 0, 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -496, 39, 95, 0, -73, 112, 0, 0, -28], [5118, 0, 0, -40, 0, 0, -45, 23, 0, 0, 0, 0, 0, 0, 0, 43, 43, 0, 0, 0], [0, 46, 66, 0, 78, 121, 0, 0, -25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -382, -1177, 0, 0, 0, -71, 0, 0, 43, -10, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 203, -42, 59, 0, -112, 70, 0, 0, 59], [0, 124, -87, 0, 56, 30, 0, 0, 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -848, 14, 62, 0, -1, 15, 0, 0, 8], [0, 120, 2, 0, 34, -65, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [36, 0, 0, -12, 0, 0, -76, -101, 0, 0, 0, 0, 0, 0, 0, -202, -202, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 260, -23, 69, 0, -229, 206, 0, 0, 60], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -61, 26, 7, 0, -68, 94, 0, 0, -29], [0, 0, 0, 0, 0, 0, 0, 0, 0, 466, 1606, 0, 0, 0, 236, 0, 0, 38, -9, 0], [-8967, 0, 0, 59, 0, 0, 103, -122, 0, 0, 0, 0, 0, 0, 0, -329, -329, 0, 0, 0], [-5766, 0, 0, -18, 0, 0, 85, -37, 0, 0, 0, 0, 0, 0, 0, 90, 90, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -577, 1287, 0, 0, 0, -355, 0, 0, 18, 29, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -804, -57, 139, 0, -144, 87, 0, 0, -14], [0, 0, 0, 0, 0, 0, 0, 0, 0, 26, 343, 0, 0, 0, -294, 0, 0, 52, 6, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 85, 20, 77, 0, 52, -32, 0, 0, -106], [0, 30, -97, 0, 60, 106, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 145, 90, 0, 64, -22, 0, 0, 50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -249, 24, -99, 0, -88, 112, 0, 0, 26], [0, 0, 0, 0, 0, 0, 0, 0, 0, 496, -993, 0, 0, 0, -396, 0, 0, 0, -32, 0], [-2043, 0, 0, -97, 0, 0, 31, 150, 0, 0, 0, 0, 0, 0, 0, -385, -385, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1130, 1137, 0, 0, 0, -225, 0, 0, 81, 0, 0], [7558, 0, 0, -30, 0, 0, 13, -179, 0, 0, 0, 0, 0, 0, 0, 150, 150, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -674, -1184, 0, 0, 0, -70, 0, 0, 4, -63, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 584, 21, -107, 0, -25, 46, 0, 0, 20], [0, 28, -10, 0, -32, -236, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-546, 0, 0, 154, 0, 0, -126, 102, 0, 0, 0, 0, 0, 0, 0, -14, -14, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1154, 732, 0, 0, 0, 376, 0, 0, 56, 9, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 140, 97, -75, 0, -211, 308, 0, 0, -16], [0, -118, -130, 0, 112, 34, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-172, 0, 0, 44, 0, 0, -72, -90, 0, 0, 0, 0, 0, 0, 0, 68, 68, 0, 0, 0], [0, 244, 114, 0, 34, -23, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-10202, 0, 0, -94, 0, 0, 58, -108, 0, 0, 0, 0, 0, 0, 0, 178, 178, 0, 0, 0], [0, -48, -74, 0, -26, -119, 0, 0, -72, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [6620, 0, 0, 124, 0, 0, 28, -129, 0, 0, 0, 0, 0, 0, 0, -306, -306, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -303, 669, 0, 0, 0, 723, 0, 0, -42, -9, 0], [9504, 0, 0, 104, 0, 0, -113, 202, 0, 0, 0, 0, 0, 0, 0, 112, 112, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1372, 39, 0, 0, 0, 116, 0, 0, 36, -12, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1540, -1372, 0, 0, 0, 179, 0, 0, -32, 50, 0], [0, -204, 126, 0, 168, 132, 0, 0, 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, -60, 162, 0, 448, -508, 0, 0, 0], [0, -248, 42, 0, 74, 62, 0, 0, 68, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 519, -965, 0, 0, 0, -459, 0, 0, -6, 89, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1330, -650, 0, 0, 0, -360, 0, 0, -42, -13, 0], [8577, 0, 0, -45, 0, 0, -61, -52, 0, 0, 0, 0, 0, 0, 0, -341, -341, 0, 0, 0], [-12162, 0, 0, 256, 0, 0, -12, 32, 0, 0, 0, 0, 0, 0, 0, -124, -124, 0, 0, 0]]
